/****************************************************************************
** Meta object code from reading C++ file 'retrieveitemstask.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.07.90/resources/imap/retrieveitemstask.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'retrieveitemstask.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17RetrieveItemsTaskE_t {};
} // unnamed namespace

template <> constexpr inline auto RetrieveItemsTask::qt_create_metaobjectdata<qt_meta_tag_ZN17RetrieveItemsTaskE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RetrieveItemsTask",
        "onFetchItemsWithoutBodiesDone",
        "",
        "QList<qint64>",
        "items",
        "onReadyForNextBatch",
        "size",
        "fetchItemsWithoutBodiesDone",
        "KJob*",
        "job",
        "onPreExpungeSelectDone",
        "onExpungeDone",
        "onFinalSelectDone",
        "onStatusDone",
        "onItemsRetrieved",
        "Akonadi::Item::List",
        "addedItems",
        "onRetrievalDone",
        "onFlagsFetchDone",
        "onSelectVanished",
        "KIMAP::ImapSet",
        "messages",
        "onSelectModified",
        "QMap<qint64,KIMAP::Message>"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onFetchItemsWithoutBodiesDone'
        QtMocHelpers::SlotData<void(const QList<qint64> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onReadyForNextBatch'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'fetchItemsWithoutBodiesDone'
        QtMocHelpers::SlotData<void(KJob *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'onPreExpungeSelectDone'
        QtMocHelpers::SlotData<void(KJob *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'onExpungeDone'
        QtMocHelpers::SlotData<void(KJob *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'onFinalSelectDone'
        QtMocHelpers::SlotData<void(KJob *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'onStatusDone'
        QtMocHelpers::SlotData<void(KJob *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'onItemsRetrieved'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'onRetrievalDone'
        QtMocHelpers::SlotData<void(KJob *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'onFlagsFetchDone'
        QtMocHelpers::SlotData<void(KJob *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'onSelectVanished'
        QtMocHelpers::SlotData<void(const KIMAP::ImapSet &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'onSelectModified'
        QtMocHelpers::SlotData<void(const QMap<qint64,KIMAP::Message> &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RetrieveItemsTask, qt_meta_tag_ZN17RetrieveItemsTaskE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RetrieveItemsTask::staticMetaObject = { {
    QMetaObject::SuperData::link<ResourceTask::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17RetrieveItemsTaskE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17RetrieveItemsTaskE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17RetrieveItemsTaskE_t>.metaTypes,
    nullptr
} };

void RetrieveItemsTask::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RetrieveItemsTask *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onFetchItemsWithoutBodiesDone((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1]))); break;
        case 1: _t->onReadyForNextBatch((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->fetchItemsWithoutBodiesDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 3: _t->onPreExpungeSelectDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 4: _t->onExpungeDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 5: _t->onFinalSelectDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 6: _t->onStatusDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 7: _t->onItemsRetrieved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 8: _t->onRetrievalDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 9: _t->onFlagsFetchDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 10: _t->onSelectVanished((*reinterpret_cast<std::add_pointer_t<KIMAP::ImapSet>>(_a[1]))); break;
        case 11: _t->onSelectModified((*reinterpret_cast<std::add_pointer_t<QMap<qint64,KIMAP::Message>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIMAP::ImapSet >(); break;
            }
            break;
        }
    }
}

const QMetaObject *RetrieveItemsTask::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RetrieveItemsTask::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17RetrieveItemsTaskE_t>.strings))
        return static_cast<void*>(this);
    return ResourceTask::qt_metacast(_clname);
}

int RetrieveItemsTask::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ResourceTask::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
